@@ -2,7 +2,7 @@
 This example show how to use the OutputWindow widget.
 """
 import sys
-from pyqode.qt import QtWidgets
+from qtpy import QtWidgets
 
 from pyqode.core.widgets import OutputWindow
 
